EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'MavenArtifacts_IncrementDownloadCount',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Increments the download count for a Maven artifact file.'
GO

IF OBJECT_ID('[MavenArtifacts_IncrementDownloadCount]') IS NOT NULL DROP PROCEDURE [MavenArtifacts_IncrementDownloadCount]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [MavenArtifacts_IncrementDownloadCount]
(
	@Feed_Id INT,
	@GroupId_Text NVARCHAR(200),
	@ArtifactId_Text NVARCHAR(100),
	@Version_Text NVARCHAR(50),
	@File_Type NVARCHAR(50),
	@FileName_Text NVARCHAR(100) = NULL
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE MAF
	   SET MAF.[Download_Count] = MAF.[Download_Count] + 1,
	       MAF.[LastDownloaded_Date] = GETUTCDATE()
	  FROM [MavenArtifactFiles] MAF
	       INNER JOIN [MavenArtifacts] MA
		           ON MA.[MavenArtifact_Id] = MAF.[MavenArtifact_Id]
	 WHERE MA.[Feed_Id] = @Feed_Id
	   AND MA.[GroupId_Text] = @GroupId_Text
	   AND MA.[ArtifactId_Text] = @ArtifactId_Text
	   AND MAF.[Version_Text] = @Version_Text
	   AND MAF.[File_Type] = @File_Type
	   AND COALESCE(MAF.[FileName_Text], @ArtifactId_Text + '-' + @Version_Text) = COALESCE(@FileName_Text, @ArtifactId_Text + '-' + @Version_Text)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [MavenArtifacts_IncrementDownloadCount] TO [ProGetUser_Role]